import { shallowRef, createVNode, render } from 'vue';
import Dialog from './dialog.mjs';
import { logWarn } from '../../../utils/index.mjs';

const createDialog = function(component, props = {}) {
  const compRef = shallowRef();
  const vm = createVNode(component, {
    ...props,
    onVnodeMounted: (vnode) => {
      var _a;
      compRef.value = (_a = vnode.component) == null ? void 0 : _a.exposed;
    }
  });
  const appendTo = document.body;
  const container = document.createElement("div");
  let dialog;
  function open(props2, confirmFn, cancelFn) {
    dialog = createVNode(Dialog, {
      ...props2,
      onSubmit,
      onCancel
    }, { default: () => vm });
    dialog.props.onClosed = () => {
      render(null, container);
    };
    if (createDialog._context) {
      dialog.appContext = createDialog._context;
    } else {
      logWarn("[Dialog] \u547D\u4EE4\u5F0F\u4F7F\u7528\u7F3A\u5C11\u4E0A\u4E0B\u6587\uFF0C\u5168\u5C40\u6CE8\u518C\u7684\u7EC4\u4EF6\u5C06\u65E0\u6CD5\u6E32\u67D3");
    }
    render(dialog, container);
    appendTo.appendChild(container.firstElementChild);
    dialog.component.exposed.open();
    return compRef;
    function onSubmit() {
      var _a;
      const res = confirmFn == null ? void 0 : confirmFn((_a = vm.component) == null ? void 0 : _a.exposed);
      if (res instanceof Promise) {
        dialog.component.exposed.setLoading(true);
        res.finally(() => {
          dialog.component.exposed.setLoading(false);
        });
      } else {
        dialog.component.exposed.setLoading(false);
      }
    }
    function onCancel() {
      cancelFn == null ? void 0 : cancelFn();
    }
  }
  function close() {
    if (!dialog)
      return;
    dialog.component.exposed.close();
  }
  return {
    open,
    close
  };
};

export { createDialog };
//# sourceMappingURL=createDialog.mjs.map
