import { defineComponent, useSlots, useAttrs, ref, watch, computed, openBlock, createBlock, unref, mergeProps, createSlots, withCtx, createElementVNode, renderSlot, createElementBlock, toDisplayString, createVNode, createCommentVNode, normalizeClass, createTextVNode } from 'vue';
import { ElDialog, ElIcon, ElScrollbar, ElButton } from 'element-plus';
import { dialogProps } from './type.mjs';
import { FullScreen } from '@element-plus/icons-vue';

const _hoisted_1 = { class: "bc-dialog-header" };
const _hoisted_2 = {
  key: 2,
  class: "text"
};
var _sfc_main = /* @__PURE__ */ defineComponent({
  ...{ name: "BcDialog" },
  __name: "dialog",
  props: dialogProps,
  emits: ["update:modelValue", "cancel", "submit"],
  setup(__props, { expose: __expose, emit }) {
    const props = __props;
    const slots = useSlots();
    const rawAttrs = useAttrs();
    const loading = ref(false);
    const visible = ref(false);
    watch(() => props.modelValue, (show) => {
      if (show === visible.value)
        return;
      visible.value = show;
      emit("update:modelValue", show);
    });
    const hasHeader = computed(() => !!slots.header);
    const hasTitle = computed(() => !!slots.title);
    const hasFooter = computed(() => !!slots.footer);
    const fullscreen = ref(false);
    const isFullscreen = computed(() => {
      if (props.needFullscreen) {
        return fullscreen.value;
      } else {
        return !!rawAttrs.fullscreen || rawAttrs.fullscreen === "";
      }
    });
    const scrollbarClass = computed(() => [
      "bc-dialog-scrollbar",
      isFullscreen.value && "bc-dialog-is-fullscreen"
    ]);
    fullscreen.value = !!rawAttrs.fullscreen;
    function handleSubmit() {
      if (!props.confirm) {
        emit("submit");
        return;
      }
      loading.value = true;
      const res = props.confirm();
      if (res instanceof Promise) {
        res.finally(() => {
          loading.value = false;
        });
      }
      emit("submit");
    }
    function close() {
      visible.value = false;
      emit("update:modelValue", false);
    }
    function open() {
      visible.value = true;
      emit("update:modelValue", true);
    }
    function handleFullScreen() {
      fullscreen.value = !fullscreen.value;
    }
    function handleCancel() {
      close();
    }
    function setLoading(state) {
      loading.value = state;
    }
    __expose({
      open,
      close,
      setLoading
    });
    return (_ctx, _cache) => {
      return openBlock(), createBlock(unref(ElDialog), mergeProps({
        "model-value": visible.value,
        "close-on-click-modal": false,
        fullscreen: fullscreen.value
      }, _ctx.$attrs, { "onUpdate:modelValue": close }), createSlots({
        header: withCtx(() => [
          createElementVNode("header", _hoisted_1, [
            hasHeader.value ? renderSlot(_ctx.$slots, "header", { key: 0 }) : hasTitle.value ? renderSlot(_ctx.$slots, "title", { key: 1 }) : (openBlock(), createElementBlock("span", _hoisted_2, toDisplayString(unref(rawAttrs).title), 1)),
            _ctx.needFullscreen ? (openBlock(), createBlock(unref(ElIcon), {
              key: 3,
              style: { "cursor": "pointer" },
              onClick: handleFullScreen
            }, {
              default: withCtx(() => [
                createVNode(unref(FullScreen))
              ]),
              _: 1
            })) : createCommentVNode("v-if", true)
          ])
        ]),
        default: withCtx(() => [
          createVNode(unref(ElScrollbar), {
            class: normalizeClass(scrollbarClass.value)
          }, {
            default: withCtx(() => [
              renderSlot(_ctx.$slots, "default")
            ]),
            _: 3
          }, 8, ["class"])
        ]),
        _: 2
      }, [
        hasFooter.value || !_ctx.noFooter ? {
          name: "footer",
          fn: withCtx(() => [
            renderSlot(_ctx.$slots, "footer", {}, () => [
              createElementVNode("footer", null, [
                createVNode(unref(ElButton), { onClick: handleCancel }, {
                  default: withCtx(() => [
                    createTextVNode(" \u53D6\u6D88 ")
                  ]),
                  _: 1
                }),
                createVNode(unref(ElButton), {
                  loading: loading.value,
                  onClick: handleSubmit
                }, {
                  default: withCtx(() => [
                    createTextVNode(" \u786E\u8BA4 ")
                  ]),
                  _: 1
                }, 8, ["loading"])
              ])
            ])
          ]),
          key: "0"
        } : void 0
      ]), 1040, ["model-value", "fullscreen"]);
    };
  }
});

export { _sfc_main as default };
//# sourceMappingURL=dialog.vue_vue_type_script_setup_true_lang.mjs.map
