import { isVNode, defineComponent, computed, ref, watch, createVNode, resolveComponent, createTextVNode, Fragment, h, mergeProps } from 'vue';
import '../../../hooks/index.mjs';
import { searchProps } from './type.mjs';
import '../../../utils/index.mjs';
import { BcUpload } from '../../upload/index.mjs';
import Button from '../../button/src/button.mjs';
import { ElForm, ElFormItem } from 'element-plus';
import { useConfigInject } from '../../../hooks/useConfigInject.mjs';
import { setValue } from '../../../utils/tools.mjs';
import { renderUnit } from '../../../utils/renderUnit.mjs';

function _isSlot(s) {
  return typeof s === "function" || Object.prototype.toString.call(s) === "[object Object]" && !isVNode(s);
}
var Search = defineComponent({
  name: "BcSearch",
  components: {
    ElForm,
    ElFormItem,
    BcUpload,
    BcButton: Button
  },
  props: searchProps,
  emits: ["update:modelValue", "reset", "create", "export"],
  setup(props, context) {
    const searchInject = useConfigInject("search");
    const needExport = computed(() => {
      var _a, _b;
      return (_b = (_a = searchInject.value) == null ? void 0 : _a.export) != null ? _b : props.export;
    });
    const paginationInject = useConfigInject("pagination");
    const pageName = computed(() => {
      var _a;
      return ((_a = paginationInject.value) == null ? void 0 : _a.pageName) || props.pageName;
    });
    const uploadVisible = ref(false);
    const searchConfig = ref();
    const defaultParams = ref();
    watch(() => props.config, (config) => {
      searchConfig.value = [...config];
    }, {
      immediate: true,
      deep: true
    });
    watch(() => props.defaultValue, (value) => {
      let val;
      if (value) {
        val = {
          ...value
        };
      } else {
        val = {
          ...props.modelValue
        };
      }
      defaultParams.value = val;
    }, {
      immediate: true
    });
    function updateData(key, val) {
      const modelValue = {
        ...props.modelValue
      };
      setValue(modelValue, key, val);
      context.emit("update:modelValue", modelValue);
    }
    function handleUpload() {
      uploadVisible.value = true;
    }
    function handleSubmit(e) {
      e.preventDefault();
    }
    function handleSearch(params) {
      var _a;
      context.emit("update:modelValue", {
        ...props.modelValue,
        ...params instanceof MouseEvent ? {} : params,
        [pageName.value]: 1
      });
      (_a = props.search) == null ? void 0 : _a.call(props);
    }
    function handleReset() {
      var _a;
      const params = {
        ...defaultParams.value
      };
      for (const key in props.modelValue) {
        const whiteList = Object.keys(params);
        if (!whiteList.includes(key)) {
          params[key] = Array.isArray(props.modelValue[key]) ? [] : void 0;
        } else {
          const val = defaultParams.value[key];
          if (Array.isArray(val)) {
            params[key] = [...val];
          } else if (isObject(val)) {
            params[key] = {
              ...val
            };
          } else {
            params[key] = val;
          }
        }
      }
      context.emit("update:modelValue", params);
      context.emit("reset");
      (_a = props.search) == null ? void 0 : _a.call(props);
    }
    function isObject(val) {
      const type = typeof val;
      return val != null && (type === "object" || type === "function");
    }
    const create = () => {
      var _a, _b;
      return ((_b = (_a = context.slots).create) == null ? void 0 : _b.call(_a)) || props.create && createVNode(resolveComponent("bc-button"), {
        "type": "primary",
        "onClick": () => {
          context.emit("create");
        }
      }, {
        default: () => [createTextVNode("\u65B0\u589E")]
      });
    };
    const search = () => {
      var _a, _b;
      return ((_b = (_a = context.slots).search) == null ? void 0 : _b.call(_a)) || createVNode(resolveComponent("bc-button"), {
        "type": "primary",
        "onClick": handleSearch
      }, {
        default: () => [createTextVNode("\u641C\u7D22")]
      });
    };
    const reset = () => {
      var _a, _b;
      return ((_b = (_a = context.slots).reset) == null ? void 0 : _b.call(_a)) || createVNode(resolveComponent("bc-button"), {
        "type": "primary",
        "class": "el-icon-refresh",
        "onClick": handleReset
      }, {
        default: () => [createTextVNode("\u91CD\u7F6E")]
      });
    };
    const upload = () => {
      var _a, _b;
      return ((_b = (_a = context.slots).upload) == null ? void 0 : _b.call(_a)) || props.upload && createVNode(resolveComponent("bc-button"), {
        "onClick": handleUpload
      }, {
        default: () => [props.upload.text || "\u5BFC\u5165"]
      });
    };
    const exportButton = () => {
      var _a, _b;
      return ((_b = (_a = context.slots).export) == null ? void 0 : _b.call(_a)) || needExport.value && createVNode(resolveComponent("bc-button"), {
        "onClick": () => {
          context.emit("export");
        }
      }, {
        default: () => [createTextVNode("\u5BFC\u51FA")]
      });
    };
    const layout = {
      create,
      search,
      reset,
      upload,
      export: exportButton,
      advance: () => createVNode(Fragment, null, null)
    };
    const node = () => createVNode("section", {
      "class": "bc-search-wraper"
    }, [createVNode(resolveComponent("el-form"), {
      "class": "bc-search-containers",
      "inline": true,
      "onSubmit": handleSubmit
    }, {
      default: () => {
        var _a;
        return [(_a = searchConfig.value) == null ? void 0 : _a.map((item) => {
          let _slot;
          return createVNode(resolveComponent("el-form-item"), {
            "label": props.nameMode === "label" ? item.name : ""
          }, _isSlot(_slot = renderUnit(h, props.modelValue, item, {
            nameMode: props.nameMode,
            handleSearch: props.search,
            updateData,
            context
          })) ? _slot : {
            default: () => [_slot]
          });
        }), createVNode(resolveComponent("el-form-item"), null, {
          default: () => {
            var _a2, _b;
            return [props.layout.map((item) => layout[item]()), (_b = (_a2 = context.slots).default) == null ? void 0 : _b.call(_a2)];
          }
        })];
      }
    }), props.upload && createVNode(resolveComponent("bc-upload"), mergeProps({
      "modelValue": uploadVisible.value,
      "onUpdate:modelValue": ($event) => uploadVisible.value = $event,
      "onSuccess": handleSearch
    }, props.upload, context.attrs), null)]);
    return node;
  }
});

export { Search as default };
//# sourceMappingURL=search.mjs.map
