import { defineComponent, computed, ref } from 'vue';
import { logWarn } from '../../../utils/index.mjs';
import { selectProps } from './type.mjs';
import '../../../hooks/index.mjs';
import { ElSelect, ElOption, ElOptionGroup } from 'element-plus';
import { useConfigInject } from '../../../hooks/useConfigInject.mjs';
import { getValue } from '../../../utils/tools.mjs';

var _sfc_main = defineComponent({
  name: "BcSelect",
  components: {
    ElSelect,
    ElOption,
    ElOptionGroup
  },
  props: selectProps,
  emits: ["update:modelValue", "update:label", "fetch", "change"],
  setup(props, context) {
    const selectInject = useConfigInject("select");
    const responseInject = useConfigInject("response");
    const arrayName = computed(() => {
      var _a;
      return ((_a = selectInject.value) == null ? void 0 : _a.arrayName) || props.arrayName;
    });
    const optionLabel = computed(() => {
      var _a;
      return ((_a = selectInject.value) == null ? void 0 : _a.label) || props.customLabel;
    });
    const optionValue = computed(() => {
      var _a;
      return ((_a = selectInject.value) == null ? void 0 : _a.value) || props.customValue;
    });
    const apis = computed(() => {
      var _a;
      return ((_a = selectInject.value) == null ? void 0 : _a.apis) || {};
    });
    const optionsName = computed(() => {
      var _a;
      return (_a = props.arrayName || arrayName.value) != null ? _a : "";
    });
    const responseWrap = computed(() => {
      var _a;
      return ((_a = responseInject.value) == null ? void 0 : _a.data) || "data";
    });
    const apiOptions = ref([]);
    const selectOptions = computed(() => {
      return [...props.options || apiOptions.value || []];
    });
    const needGroup = computed(() => {
      if (!props.group) {
        return false;
      }
      return selectOptions.value.some((item) => item.children);
    });
    const displayText = computed(() => {
      const value = Array.isArray(props.modelValue) ? props.modelValue : [props.modelValue];
      const res = [];
      value.forEach((item) => {
        let obj = {};
        if (props.modelValue instanceof Object) {
          obj = props.modelValue;
        } else {
          obj = selectOptions.value.find((each) => each[optionValue.value] === item) || {};
        }
        res.push(obj ? obj[optionLabel.value] : "");
      });
      return res.join(",");
    });
    const selectWidth = computed(() => {
      if (!props.width) {
        return "";
      }
      if (typeof props.width === "string") {
        return props.width;
      } else {
        return props.width + "px";
      }
    });
    props.immediate && getList();
    props.defaultValue && context.emit("update:modelValue", props.defaultValue);
    function getList() {
      let api = props.api;
      if (typeof props.api === "string") {
        api = apis.value[props.api];
      }
      if (typeof api === "function") {
        api().then((data) => {
          const response = data[responseWrap.value];
          if (!response) {
            logWarn("[select]api\u8FD4\u56DE\u503C\u5F02\u5E38");
            return;
          }
          if (Array.isArray(response) && response) {
            apiOptions.value = response;
          } else if (response instanceof Object) {
            apiOptions.value = response[optionsName.value];
          } else {
            logWarn("[bc-select]api\u8FD4\u56DE\u503C\u89E3\u6790\u5931\u8D25");
          }
          context.emit("fetch", apiOptions.value);
        });
      }
    }
    function hasValue(item) {
      const value = getValue(item, optionLabel.value);
      if (value === "" || !!value) {
        return value;
      } else {
        return typeof item === "object" ? "" : item;
      }
    }
    function getObject(value) {
      if (typeof value === "object") {
        return value;
      }
      const res = selectOptions.value.find((item) => item[optionValue.value] === (value || props.modelValue));
      if (!res) {
        return {};
      }
      return res;
    }
    function getLabel(val) {
      const value = val || props.modelValue;
      if (Array.isArray(value)) {
        return value.reduce((res, curr) => {
          const result = selectOptions.value.find((item) => item[optionValue.value] === curr) || {};
          if (!result) {
            res.push("");
          }
          res.push(result[optionLabel.value]);
          return res;
        }, []);
      } else {
        const res = selectOptions.value.find((item) => item[optionValue.value] === value);
        if (!res) {
          return "";
        }
        return res[optionLabel.value];
      }
    }
    function getOptions() {
      return selectOptions.value;
    }
    function emitValue(val) {
      context.emit("update:modelValue", val);
      context.emit("change", val, getObject(val));
    }
    function emitLabel(val) {
      context.emit("update:label", getLabel(val));
    }
    context.expose({
      getOptions,
      getLabel
    });
    return {
      needGroup,
      displayText,
      selectOptions,
      selectWidth,
      optionValue,
      hasValue,
      getObject,
      getLabel,
      getOptions,
      emitLabel,
      emitValue
    };
  }
});

export { _sfc_main as default };
//# sourceMappingURL=select.vue_vue_type_script_lang.mjs.map
