import { defineComponent, computed, ref, reactive, watch, onActivated, createVNode, resolveComponent, mergeProps, withDirectives, resolveDirective } from 'vue';
import '../../../hooks/index.mjs';
import customTable from './customTable.mjs';
import customPagination from './pagination.mjs';
import { tableProps } from './type.mjs';
import { useConfigInject } from '../../../hooks/useConfigInject.mjs';

var Table = defineComponent({
  name: "BcTable",
  components: {
    CustomTable: customTable,
    CustomPagination: customPagination
  },
  props: tableProps,
  emits: ["update:modelValue"],
  setup(props, context) {
    const tableInject = useConfigInject("table");
    const arrayName = computed(() => {
      var _a;
      return ((_a = tableInject.value) == null ? void 0 : _a.arrayName) || props.arrayName;
    });
    const totalName = computed(() => {
      var _a;
      return ((_a = tableInject.value) == null ? void 0 : _a.totalName) || "total";
    });
    const paginationInject = useConfigInject("pagination");
    const pageSizeName = computed(() => {
      var _a;
      return ((_a = paginationInject.value) == null ? void 0 : _a.pageSizeName) || "rows";
    });
    const pageName = computed(() => {
      var _a;
      return ((_a = paginationInject.value) == null ? void 0 : _a.pageName) || "page";
    });
    const responseInject = useConfigInject("response");
    const responseWrap = computed(() => {
      var _a;
      return ((_a = responseInject.value) == null ? void 0 : _a.data) || "data";
    });
    const arrayData = ref([]);
    const arrayTotal = ref(0);
    const simpleTable = reactive({
      page: 1,
      rows: 5
    });
    const loading = ref(false);
    const tableConfig = ref([{}]);
    const customTableRef = ref();
    const tableDataName = computed(() => {
      var _a;
      if (props.arrayName == null) {
        return null;
      } else {
        return (_a = props.arrayName || arrayName.value) != null ? _a : "";
      }
    });
    const tableData = computed(() => {
      if (props.data && props.data.length > 0) {
        return props.data || [];
      } else {
        return props.filter ? props.filter(arrayData.value) : arrayData.value;
      }
    });
    const totalColumn = computed(() => {
      const {
        includes = [],
        parentProp = null
      } = props.colspanOptions;
      const totalColumn2 = {};
      const whiteList = {};
      includes.forEach((item) => {
        whiteList[item] = 0;
      });
      tableData.value.forEach((row) => {
        Object.keys(row).forEach((key) => {
          if (!Object.keys(whiteList).includes(key)) {
            return;
          }
          const spanKey = parentProp ? `${row[parentProp]}_${key}_${row[key]}` : `${key}_${row[key]}`;
          const column = totalColumn2[spanKey];
          if (!row[key]) {
            whiteList[key] += 1;
            return;
          }
          if (column != null) {
            Object.assign(totalColumn2[spanKey], {
              num: column.num + 1
            });
          } else {
            totalColumn2[spanKey] = {
              index: whiteList[key],
              num: 1
            };
          }
          whiteList[key] += 1;
        });
      });
      return totalColumn2;
    });
    const searchModel = computed({
      get() {
        const {
          [pageName.value]: page,
          [pageSizeName.value]: rows,
          ...params
        } = props.modelValue;
        return {
          page,
          rows,
          ...params
        };
      },
      set(obj) {
        updateParams(obj);
      }
    });
    const simpleData = computed(() => {
      var _a;
      const {
        page,
        rows
      } = simpleTable;
      const start = (page - 1) * rows;
      const end = page * rows;
      return (_a = props.data) == null ? void 0 : _a.slice(start, end);
    });
    watch(() => props.config, (config) => {
      config && (tableConfig.value = [...config]);
    }, {
      deep: true,
      immediate: true
    });
    if (props.activatedUpdate) {
      onActivated(() => {
        init();
      });
    } else {
      init();
    }
    function init() {
      if (props.custom) {
        props.api && props.immediate && props.api();
      } else {
        if (props.load && props.immediate && props.api) {
          loading.value = true;
        }
        props.api && props.immediate && getList();
      }
    }
    function getList() {
      var _a;
      if (!props.custom && props.load) {
        loading.value = true;
      }
      const wrap = responseWrap.value;
      const array = tableDataName.value;
      return (_a = props.api) == null ? void 0 : _a.call(props).then((data) => {
        const response = data[wrap];
        arrayData.value = (array ? response[array] : data[wrap]) || [];
        loading.value = false;
        arrayTotal.value = response[totalName.value] || 0;
        return Promise.resolve(arrayData.value);
      }).catch(() => {
        loading.value = false;
        arrayData.value = [];
        arrayTotal.value = 0;
      });
    }
    function updateParams(params) {
      const {
        page,
        rows,
        ...args
      } = params;
      context.emit("update:modelValue", {
        ...args,
        [pageName.value]: page,
        [pageSizeName.value]: rows
      });
    }
    function spanMethod({
      row,
      column,
      rowIndex
    }) {
      const {
        includes = [],
        parentProp = null
      } = props.colspanOptions;
      const key = column.property;
      const spanKey = parentProp ? `${row[parentProp]}_${key}_${row[key]}` : `${key}_${row[key]}`;
      if (!includes.includes(key) || row[key] == null) {
        return {
          colspan: 1,
          rowspan: 1
        };
      }
      if (rowIndex === totalColumn.value[spanKey].index) {
        return {
          colspan: 1,
          rowspan: totalColumn.value[spanKey].num
        };
      } else {
        return [0, 0];
      }
    }
    function handlePageChange(page) {
      var _a;
      searchModel.value.page = page;
      updateParams(searchModel.value);
      props.custom ? (_a = props.api) == null ? void 0 : _a.call(props) : getList();
    }
    function handleRowsChange(rows) {
      searchModel.value.rows = rows;
      handlePageChange(1);
    }
    function handleSimplePageChange(page) {
      simpleTable.page = page;
    }
    function handleSimpleRowsChange(rows) {
      simpleTable.rows = rows;
    }
    const pagination = () => {
      if (!props.pagination) {
        return null;
      }
      return props.simple ? createVNode(resolveComponent("custom-pagination"), mergeProps({
        "currentPage": simpleTable.page,
        "onUpdate:currentPage": ($event) => simpleTable.page = $event,
        "pageSize": simpleTable.rows,
        "onUpdate:pageSize": ($event) => simpleTable.rows = $event
      }, {
        "onUpdate:currentPage": handleSimplePageChange,
        "onUpdate:pageSize": handleSimpleRowsChange
      }, {
        "total": tableData.value.length,
        "layout": "prev, pager, next"
      }), null) : createVNode(resolveComponent("custom-pagination"), mergeProps({
        "currentPage": searchModel.value.page,
        "onUpdate:currentPage": ($event) => searchModel.value.page = $event,
        "pageSize": searchModel.value.rows,
        "onUpdate:pageSize": ($event) => searchModel.value.rows = $event
      }, {
        "onUpdate:currentPage": handlePageChange,
        "onUpdate:pageSize": handleRowsChange
      }, context.attrs, {
        "total": props.custom ? props.total : arrayTotal.value
      }), null);
    };
    context.expose({
      getList,
      clearSelection: () => customTableRef.value.clearSelection(),
      getRef: () => customTableRef.value.getRef()
    });
    return () => createVNode("section", {
      "class": "bc-table-wrap"
    }, [withDirectives(createVNode(resolveComponent("custom-table"), mergeProps({
      "class": "bc-table",
      "ref": customTableRef,
      "config": tableConfig.value,
      "data": props.simple ? simpleData.value : tableData.value,
      "span-method": props.colspanOptions ? spanMethod : null,
      "hidden-current": !!props.colspanOptions,
      "body-border": !!props.colspanOptions
    }, context.attrs), context.slots), [[resolveDirective("loading"), loading.value]]), pagination()]);
  }
});

export { Table as default };
//# sourceMappingURL=table.mjs.map
