import { ref, getCurrentInstance, inject, computed, provide, unref } from 'vue';
import '../components/configProvider/index.mjs';
import { logWarn } from '../utils/index.mjs';
import { configProviderContextKey } from '../components/configProvider/src/type.mjs';

const globalConfig = ref();
function useConfigInject(name, defaultValue) {
  const config = getCurrentInstance() ? inject(configProviderContextKey, globalConfig) : globalConfig;
  if (name) {
    return computed(() => {
      var _a, _b;
      return (_b = (_a = config.value) == null ? void 0 : _a[name]) != null ? _b : defaultValue;
    });
  } else {
    return globalConfig;
  }
}
const provideGlobalConfig = (config, app, global = false) => {
  var _a;
  const inSetup = !!getCurrentInstance();
  const oldConfig = inSetup ? useConfigInject() : void 0;
  const provideFn = (_a = app == null ? void 0 : app.provide) != null ? _a : inSetup ? provide : void 0;
  if (!provideFn) {
    logWarn("provideGlobalConfig() can only be used inside setup()");
    return;
  }
  const context = computed(() => {
    const cfg = unref(config);
    if (!(oldConfig == null ? void 0 : oldConfig.value))
      return cfg;
    return mergeConfig(oldConfig.value, cfg);
  });
  provideFn(configProviderContextKey, context);
  if (global || !globalConfig.value) {
    globalConfig.value = context.value;
  }
  return context;
};
function mergeConfig(a, b) {
  if (!a || !b) {
    return a || b;
  }
  const obj = {};
  if (isObject(a) && isObject(b)) {
    const keys = new Set([...Object.keys(a), ...Object.keys(b)]);
    for (const key of keys) {
      obj[key] = mergeConfig(a[key], b[key]);
    }
  } else if (isObject(a)) {
    Object.assign(obj, a);
  } else if (isObject(b)) {
    Object.assign(obj, b);
  } else {
    return a || b;
  }
  return obj;
}
function isObject(a) {
  return Object.prototype.toString.call(a) === "[object Object]";
}

export { provideGlobalConfig, useConfigInject };
//# sourceMappingURL=useConfigInject.mjs.map
