import { createVNode, mergeProps } from 'vue';
import '../components/index.mjs';
import './index.mjs';
import { setValue, getValue } from './tools.mjs';
import { BcInput } from '../components/input/index.mjs';
import { BcSelect } from '../components/select/index.mjs';
import { BcDatePicker } from '../components/date-picker/index.mjs';

function updateData(params, prop, val, context) {
  if (context == null ? void 0 : context.updateData) {
    context.updateData(prop, val);
  } else {
    setValue(params, prop, val);
  }
}
function handleSearch(context) {
  if (context == null ? void 0 : context.handleSearch) {
    context.handleSearch();
  }
}
const renderUnit = (h, value, config, context) => {
  var _a;
  const {
    catalog,
    prop,
    name,
    options,
    ...params
  } = config;
  const modelValue = getValue(value, prop);
  if (catalog === "input") {
    return createVNode(BcInput, mergeProps({
      "model-value": modelValue
    }, {
      placeholder: (context == null ? void 0 : context.nameMode) === "placeholder" ? name : params.placeholder,
      "onUpdate:modelValue": (val) => updateData(value, prop, val, context),
      onKeyup: (e) => e.code === "Enter" && handleSearch(context)
    }, params), null);
  } else if (catalog === "select") {
    return createVNode(BcSelect, mergeProps({
      "model-value": modelValue
    }, {
      "onUpdate:modelValue": (val) => updateData(value, prop, val, context),
      onChange: () => handleSearch(context),
      placeholder: (context == null ? void 0 : context.nameMode) === "placeholder" ? name : params.placeholder
    }, {
      "options": options
    }, params), null);
  } else if (catalog === "datepicker") {
    return createVNode(BcDatePicker, mergeProps({
      "model-value": modelValue
    }, {
      startPlaceholder: "\u5F00\u59CB\u65E5\u671F",
      endPlaceholder: "\u7ED3\u675F\u65E5\u671F",
      rangeSeparator: "\u81F3",
      ...params,
      "onUpdate:modelValue": (val) => updateData(value, prop, val, context),
      onChange: () => handleSearch(context)
    }, params), null);
  } else {
    return (_a = context == null ? void 0 : context.context) == null ? void 0 : _a.slots[config.prop];
  }
};

export { renderUnit };
//# sourceMappingURL=renderUnit.mjs.map
