'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var vue = require('vue');
var elementPlus = require('element-plus');
var type = require('./type.js');
var iconsVue = require('@element-plus/icons-vue');

const _hoisted_1 = { class: "bc-dialog-header" };
const _hoisted_2 = {
  key: 2,
  class: "text"
};
var _sfc_main = /* @__PURE__ */ vue.defineComponent({
  ...{ name: "BcDialog" },
  __name: "dialog",
  props: type.dialogProps,
  emits: ["update:modelValue", "cancel", "submit"],
  setup(__props, { expose: __expose, emit }) {
    const props = __props;
    const slots = vue.useSlots();
    const rawAttrs = vue.useAttrs();
    const loading = vue.ref(false);
    const visible = vue.ref(false);
    vue.watch(() => props.modelValue, (show) => {
      if (show === visible.value)
        return;
      visible.value = show;
      emit("update:modelValue", show);
    });
    const hasHeader = vue.computed(() => !!slots.header);
    const hasTitle = vue.computed(() => !!slots.title);
    const hasFooter = vue.computed(() => !!slots.footer);
    const fullscreen = vue.ref(false);
    const isFullscreen = vue.computed(() => {
      if (props.needFullscreen) {
        return fullscreen.value;
      } else {
        return !!rawAttrs.fullscreen || rawAttrs.fullscreen === "";
      }
    });
    const scrollbarClass = vue.computed(() => [
      "bc-dialog-scrollbar",
      isFullscreen.value && "bc-dialog-is-fullscreen"
    ]);
    fullscreen.value = !!rawAttrs.fullscreen;
    function handleSubmit() {
      if (!props.confirm) {
        emit("submit");
        return;
      }
      loading.value = true;
      const res = props.confirm();
      if (res instanceof Promise) {
        res.finally(() => {
          loading.value = false;
        });
      }
      emit("submit");
    }
    function close() {
      visible.value = false;
      emit("update:modelValue", false);
    }
    function open() {
      visible.value = true;
      emit("update:modelValue", true);
    }
    function handleFullScreen() {
      fullscreen.value = !fullscreen.value;
    }
    function handleCancel() {
      close();
    }
    function setLoading(state) {
      loading.value = state;
    }
    __expose({
      open,
      close,
      setLoading
    });
    return (_ctx, _cache) => {
      return vue.openBlock(), vue.createBlock(vue.unref(elementPlus.ElDialog), vue.mergeProps({
        "model-value": visible.value,
        "close-on-click-modal": false,
        fullscreen: fullscreen.value
      }, _ctx.$attrs, { "onUpdate:modelValue": close }), vue.createSlots({
        header: vue.withCtx(() => [
          vue.createElementVNode("header", _hoisted_1, [
            hasHeader.value ? vue.renderSlot(_ctx.$slots, "header", { key: 0 }) : hasTitle.value ? vue.renderSlot(_ctx.$slots, "title", { key: 1 }) : (vue.openBlock(), vue.createElementBlock("span", _hoisted_2, vue.toDisplayString(vue.unref(rawAttrs).title), 1)),
            _ctx.needFullscreen ? (vue.openBlock(), vue.createBlock(vue.unref(elementPlus.ElIcon), {
              key: 3,
              style: { "cursor": "pointer" },
              onClick: handleFullScreen
            }, {
              default: vue.withCtx(() => [
                vue.createVNode(vue.unref(iconsVue.FullScreen))
              ]),
              _: 1
            })) : vue.createCommentVNode("v-if", true)
          ])
        ]),
        default: vue.withCtx(() => [
          vue.createVNode(vue.unref(elementPlus.ElScrollbar), {
            class: vue.normalizeClass(scrollbarClass.value)
          }, {
            default: vue.withCtx(() => [
              vue.renderSlot(_ctx.$slots, "default")
            ]),
            _: 3
          }, 8, ["class"])
        ]),
        _: 2
      }, [
        hasFooter.value || !_ctx.noFooter ? {
          name: "footer",
          fn: vue.withCtx(() => [
            vue.renderSlot(_ctx.$slots, "footer", {}, () => [
              vue.createElementVNode("footer", null, [
                vue.createVNode(vue.unref(elementPlus.ElButton), { onClick: handleCancel }, {
                  default: vue.withCtx(() => [
                    vue.createTextVNode(" \u53D6\u6D88 ")
                  ]),
                  _: 1
                }),
                vue.createVNode(vue.unref(elementPlus.ElButton), {
                  loading: loading.value,
                  onClick: handleSubmit
                }, {
                  default: vue.withCtx(() => [
                    vue.createTextVNode(" \u786E\u8BA4 ")
                  ]),
                  _: 1
                }, 8, ["loading"])
              ])
            ])
          ]),
          key: "0"
        } : void 0
      ]), 1040, ["model-value", "fullscreen"]);
    };
  }
});

exports["default"] = _sfc_main;
//# sourceMappingURL=dialog.vue_vue_type_script_setup_true_lang.js.map
