'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var vue = require('vue');
require('../../../hooks/index.js');
var type = require('./type.js');
require('../../../utils/index.js');
var index = require('../../upload/index.js');
var button = require('../../button/src/button.js');
var elementPlus = require('element-plus');
var useConfigInject = require('../../../hooks/useConfigInject.js');
var tools = require('../../../utils/tools.js');
var renderUnit = require('../../../utils/renderUnit.js');

function _isSlot(s) {
  return typeof s === "function" || Object.prototype.toString.call(s) === "[object Object]" && !vue.isVNode(s);
}
var Search = vue.defineComponent({
  name: "BcSearch",
  components: {
    ElForm: elementPlus.ElForm,
    ElFormItem: elementPlus.ElFormItem,
    BcUpload: index.BcUpload,
    BcButton: button["default"]
  },
  props: type.searchProps,
  emits: ["update:modelValue", "reset", "create", "export"],
  setup(props, context) {
    const searchInject = useConfigInject.useConfigInject("search");
    const needExport = vue.computed(() => {
      var _a, _b;
      return (_b = (_a = searchInject.value) == null ? void 0 : _a.export) != null ? _b : props.export;
    });
    const paginationInject = useConfigInject.useConfigInject("pagination");
    const pageName = vue.computed(() => {
      var _a;
      return ((_a = paginationInject.value) == null ? void 0 : _a.pageName) || props.pageName;
    });
    const uploadVisible = vue.ref(false);
    const searchConfig = vue.ref();
    const defaultParams = vue.ref();
    vue.watch(() => props.config, (config) => {
      searchConfig.value = [...config];
    }, {
      immediate: true,
      deep: true
    });
    vue.watch(() => props.defaultValue, (value) => {
      let val;
      if (value) {
        val = {
          ...value
        };
      } else {
        val = {
          ...props.modelValue
        };
      }
      defaultParams.value = val;
    }, {
      immediate: true
    });
    function updateData(key, val) {
      const modelValue = {
        ...props.modelValue
      };
      tools.setValue(modelValue, key, val);
      context.emit("update:modelValue", modelValue);
    }
    function handleUpload() {
      uploadVisible.value = true;
    }
    function handleSubmit(e) {
      e.preventDefault();
    }
    function handleSearch(params) {
      var _a;
      context.emit("update:modelValue", {
        ...props.modelValue,
        ...params instanceof MouseEvent ? {} : params,
        [pageName.value]: 1
      });
      (_a = props.search) == null ? void 0 : _a.call(props);
    }
    function handleReset() {
      var _a;
      const params = {
        ...defaultParams.value
      };
      for (const key in props.modelValue) {
        const whiteList = Object.keys(params);
        if (!whiteList.includes(key)) {
          params[key] = Array.isArray(props.modelValue[key]) ? [] : void 0;
        } else {
          const val = defaultParams.value[key];
          if (Array.isArray(val)) {
            params[key] = [...val];
          } else if (isObject(val)) {
            params[key] = {
              ...val
            };
          } else {
            params[key] = val;
          }
        }
      }
      context.emit("update:modelValue", params);
      context.emit("reset");
      (_a = props.search) == null ? void 0 : _a.call(props);
    }
    function isObject(val) {
      const type = typeof val;
      return val != null && (type === "object" || type === "function");
    }
    const create = () => {
      var _a, _b;
      return ((_b = (_a = context.slots).create) == null ? void 0 : _b.call(_a)) || props.create && vue.createVNode(vue.resolveComponent("bc-button"), {
        "type": "primary",
        "onClick": () => {
          context.emit("create");
        }
      }, {
        default: () => [vue.createTextVNode("\u65B0\u589E")]
      });
    };
    const search = () => {
      var _a, _b;
      return ((_b = (_a = context.slots).search) == null ? void 0 : _b.call(_a)) || vue.createVNode(vue.resolveComponent("bc-button"), {
        "type": "primary",
        "onClick": handleSearch
      }, {
        default: () => [vue.createTextVNode("\u641C\u7D22")]
      });
    };
    const reset = () => {
      var _a, _b;
      return ((_b = (_a = context.slots).reset) == null ? void 0 : _b.call(_a)) || vue.createVNode(vue.resolveComponent("bc-button"), {
        "type": "primary",
        "class": "el-icon-refresh",
        "onClick": handleReset
      }, {
        default: () => [vue.createTextVNode("\u91CD\u7F6E")]
      });
    };
    const upload = () => {
      var _a, _b;
      return ((_b = (_a = context.slots).upload) == null ? void 0 : _b.call(_a)) || props.upload && vue.createVNode(vue.resolveComponent("bc-button"), {
        "onClick": handleUpload
      }, {
        default: () => [props.upload.text || "\u5BFC\u5165"]
      });
    };
    const exportButton = () => {
      var _a, _b;
      return ((_b = (_a = context.slots).export) == null ? void 0 : _b.call(_a)) || needExport.value && vue.createVNode(vue.resolveComponent("bc-button"), {
        "onClick": () => {
          context.emit("export");
        }
      }, {
        default: () => [vue.createTextVNode("\u5BFC\u51FA")]
      });
    };
    const layout = {
      create,
      search,
      reset,
      upload,
      export: exportButton,
      advance: () => vue.createVNode(vue.Fragment, null, null)
    };
    const node = () => vue.createVNode("section", {
      "class": "bc-search-wraper"
    }, [vue.createVNode(vue.resolveComponent("el-form"), {
      "class": "bc-search-containers",
      "inline": true,
      "onSubmit": handleSubmit
    }, {
      default: () => {
        var _a;
        return [(_a = searchConfig.value) == null ? void 0 : _a.map((item) => {
          let _slot;
          return vue.createVNode(vue.resolveComponent("el-form-item"), {
            "label": props.nameMode === "label" ? item.name : ""
          }, _isSlot(_slot = renderUnit.renderUnit(vue.h, props.modelValue, item, {
            nameMode: props.nameMode,
            handleSearch: props.search,
            updateData,
            context
          })) ? _slot : {
            default: () => [_slot]
          });
        }), vue.createVNode(vue.resolveComponent("el-form-item"), null, {
          default: () => {
            var _a2, _b;
            return [props.layout.map((item) => layout[item]()), (_b = (_a2 = context.slots).default) == null ? void 0 : _b.call(_a2)];
          }
        })];
      }
    }), props.upload && vue.createVNode(vue.resolveComponent("bc-upload"), vue.mergeProps({
      "modelValue": uploadVisible.value,
      "onUpdate:modelValue": ($event) => uploadVisible.value = $event,
      "onSuccess": handleSearch
    }, props.upload, context.attrs), null)]);
    return node;
  }
});

exports["default"] = Search;
//# sourceMappingURL=search.js.map
